@@ -22,29 +22,25 @@ $Data::Dumper::Sortkeys = 1;
 
 =head1 NAME
 
-Lavoco::Web::App - Experimental framework with 2 constraints, FastCGI and Template::Toolkit.
-
-Framework to run small web apps, URL dispatching based on a flexible config file, rendering Template::Toolkit templates.
+Lavoco::Web::App - Experimental framework with two constraints: FastCGI and Template::Toolkit.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
 
-A FastCGI web-app for serving Template::Toolkit templates.
-
-This is an experimental framework to control various small websites, use at your own risk.
+Framework to run small web apps, URL dispatching based on a flexible config file, rendering Template::Toolkit templates, running as a FastCGI application.
 
  use Lavoco::Web::App;
  
- my $app = Lavoco::Web::App->new( name => 'Example' );
+ my $app = Lavoco::Web::App->new;
  
  my $action = lc( $ARGV[0] );   # (start|stop|restart)
  
@@ -64,7 +60,6 @@ Creates a new instance of the web-app object.
 
 =cut
 
-has  name      => ( is => 'rw', isa => 'Str',  default => 'App' );
 has  processes => ( is => 'rw', isa => 'Int',  default => 5         );
 has  base      => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_base'      );
 has  dev       => ( is => 'rw', isa => 'Bool', lazy => 1, builder => '_build_dev'       );
@@ -116,10 +111,6 @@ sub _build_filename
     return $self->base . '/app.json';
 }
 
-=head3 name
-
-The identifier for the web-app, used as the FastCGI-process title.
-
 =head3 base
 
 The base directory of the application, detected using L<FindBin>.
@@ -184,7 +175,6 @@ sub start
         listen     => [ $self->_socket ],
         pid        =>   $self->_pid,
         detach     =>   1,
-        proc_title =>   $self->name,
     );
     
     $server->run( $self->_handler );
